=======
Credits
=======

Development Lead
----------------

* Arne Tillmann <arne.tillmann.vellmar@gmail.com>

Contributors
------------
* Anton Thielmann <anton.thielmann@stud.uni-goettingen.de>
* Christoph Weisser <c.weisser@stud.uni-goettingen.de>
* Benjamin Säfken <benjamin.saefken@uni-goettingen.de>
* Alexander Silbersdorff <asilbersdorff@uni-goettingen.de>
* Thomas Kneib <Thomas.Kneib@wiwi.uni-goettingen.de>

Special thanks
--------------



This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
